@@ -2,7 +2,12 @@
 #' New duplicate analysis functions
 #'
 #' @description `function_duplicate_cols()` is an internal (non-exported)
-#'   function factory. It creates new functions
+#'   function factory. It creates new functions that take a data frame and affix
+#'   one new column to the right of each existing column.
+#'
+#'   These functions were made by `function_duplicate_cols()`:
+#'   - [`duplicate_tally()`]
+#'   - [`duplicate_detect()`]
 #'
 #' @param code_new_cols Expression which the factory-made function will evaluate
 #'   at runtime. It computes the vector that will be split into the new columns
@@ -14,11 +19,13 @@
 #'   newly created columns.
 #' @param name_class String. Name of the class which the factory-made function
 #'   will add to the tibble that it returns.
-#' @param include_numeric_only_arg Boolean. Should the factory-made function
+#' @param include_numeric_only_arg Logical. Should the factory-made function
 #'   have the deprecated `numeric_only = TRUE` argument? Only for compatibility
 #'   with older versions of scrutiny (i.e., before 0.3.0). Default is `FALSE`.
 #'
-#' @return Function such as `duplicate_detect()` or `duplicate_tally()`.
+#' @include utils.R
+#'
+#' @return Function such as [`duplicate_tally()`] or [`duplicate_detect()`].
 #'
 #' @noRd
 
@@ -55,6 +62,14 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
     body = rlang::expr({
       `!!`(numeric_only_check)
 
+      # Type checking:
+      if (!rlang::is_vector(x)) {
+        cli::cli_abort(c(
+          "`x` must be a data frame or other type of vector.",
+          "x" = paste0("It is ", an_a_type(x), ".")
+        ))
+      }
+
       # Convert `x` to a data frame if needed:
       x_was_named <- rlang::is_named(x)
       if (!x_was_named || !is.data.frame(x)) {
@@ -81,8 +96,6 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
       x <- x %>%
         tidyr::pivot_longer(
           cols = everything(),
-          # names_to = "name",
-          # values_to = "value",
           values_transform = as.character,
           cols_vary = "slowest"
         ) %>%
@@ -100,11 +113,11 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
       }
 
       # Gather both vectors in a tibble, so that each test value is joined by a
-      # Boolean value indicating whether it has any duplicates in the rest of
+      # Logical value indicating whether it has any duplicates in the rest of
       # the vector (i.e., in the flattened original data frame). Split the
       # two-column tibble and rearrange it into one of the same shape as the
       # original data frame, but with every test value accompanied by its
-      # corresponding Boolean value to the right, as above. Also, add the
+      # corresponding logical value to the right, as above. Also, add the
       # "scr_dup_detect" class added, which is recognized by the `audit()`
       # generic:
       x %>%
@@ -131,7 +144,8 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
 #' @description `r lifecycle::badge('superseded')`
 #'
 #'   `duplicate_detect()` is superseded because it's less informative than
-#'   `duplicate_tally()` and `duplicate_count()`. Use these functions instead.
+#'   [`duplicate_tally()`] and [`duplicate_count()`]. Use these functions
+#'   instead.
 #'
 #'   For every value in a vector or data frame, `duplicate_detect()` tests
 #'   whether there is at least one identical value. Test results are presented
@@ -140,7 +154,7 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
 #'   This function is a blunt tool designed for initial data checking. Don't put
 #'   too much weight on its results.
 #'
-#'   For summary statistics, call `audit()` on the results.
+#'   For summary statistics, call [`audit()`] on the results.
 #'
 #' @details This function is not very informative with many input values that
 #'   only have a few characters each. Many of them may have duplicates just by
@@ -153,7 +167,7 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
 #' @param x Vector or data frame.
 #' @param ignore Optionally, a vector of values that should not be checked. In
 #'   the test result columns, they will be marked `NA`.
-#' @param colname_end String. Name ending of the Boolean test result columns.
+#' @param colname_end String. Name ending of the logical test result columns.
 #'   Default is `"dup"`.
 #' @param numeric_only [[Deprecated]] No longer used: All values are coerced to
 #'   character.
@@ -164,9 +178,9 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
 #'   The tibble has the `scr_dup_detect` class, which is recognized by the
 #'   `audit()` generic.
 
-#' @section Summaries with `audit()`: There is an S3 method for the `audit()`
-#'   generic, so you can call `audit()` following `duplicate_detect()`. It
-#'   returns a tibble with these columns ---
+#' @section Summaries with [`audit()`]: There is an S3 method for the
+#'   [`audit()`] generic, so you can call [`audit()`] following
+#'   `duplicate_detect()`. It returns a tibble with these columns ---
 #'   - `term`: The original data frame's variables.
 #'   - `dup_count`: Number of "duplicated" values of that `term` variable: those
 #'   which have at least one duplicate anywhere in the data frame.
@@ -178,12 +192,12 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
 #'   `dup_rate` column.
 #'
 #' @seealso
-#'  - `duplicate_tally()` to count instances of a value instead of just stating
-#' whether it is duplicated.
-#'  - `duplicate_count()` for a frequency table.
-#'  - `duplicate_count_colpair()` to check each combination of columns for
+#'  - [`duplicate_tally()`] to count instances of a value instead of just
+#'  stating whether it is duplicated.
+#'  - [`duplicate_count()`] for a frequency table.
+#'  - [`duplicate_count_colpair()`] to check each combination of columns for
 #' duplicates.
-#'  - `janitor::get_dupes()` to search for duplicate rows.
+#'  - [`janitor::get_dupes()`] to search for duplicate rows.
 #'
 #' @include utils.R
 #'
@@ -206,7 +220,7 @@ function_duplicate_cols <- function(code_new_cols, default_end, name_class,
 #'   duplicate_detect(ignore = c(8.131, 7.574))
 
 duplicate_detect <- function_duplicate_cols(
-  # Create a Boolean vector pointing out duplicates within the vector of all
+  # Create a logical vector pointing out duplicates within the vector of all
   # input values, both from the start forward and from the end backward:
   code_new_cols = duplicated(x) | duplicated(x, fromLast = TRUE),
   default_end = "dup",
@@ -224,9 +238,9 @@ duplicate_detect <- function_duplicate_cols(
 #'   counts how often it appears in total. Tallies are presented next to each
 #'   value.
 #'
-#'   For summary statistics, call `audit()` on the results.
+#'   For summary statistics, call [`audit()`] on the results.
 #'
-#' @param colname_end String. Name ending of the Boolean test result columns.
+#' @param colname_end String. Name ending of the logical test result columns.
 #'   Default is `"n"`.
 #'
 #' @inheritParams duplicate_detect
@@ -238,15 +252,15 @@ duplicate_detect <- function_duplicate_cols(
 #'   The tibble has the `scr_dup_detect` class, which is recognized by the
 #'   `audit()` generic.
 #'
-#' @section Summaries with `audit()`: There is an S3 method for the `audit()`
-#'   generic, so you can call `audit()` following `duplicate_tally()`. It
+#' @section Summaries with [`audit()`]: There is an S3 method for the [`audit()`]
+#'   generic, so you can call [`audit()`] following `duplicate_tally()`. It
 #'   returns a tibble with summary statistics.
 #'
 #' @seealso
-#'  - `duplicate_count()` for a frequency table.
-#'  - `duplicate_count_colpair()` to check each combination of columns for
+#'  - [`duplicate_count()`] for a frequency table.
+#'  - [`duplicate_count_colpair()`] to check each combination of columns for
 #' duplicates.
-#'  - `janitor::get_dupes()` to search for duplicate rows.
+#'  - [`janitor::get_dupes()`] to search for duplicate rows.
 #'
 #' @include utils.R
 
