@@ -41,9 +41,9 @@ check_factory_key_args_values <- function(data, key_cols_call) {
     # Prepare an error message. It might be subsequently appended...
     msg_error <- c(
       "!" = "{offenders} {msg_is_colname} of `data`.",
-      "x" = "The {offenders_names[1]} argument of \\
-      {name_current_fn} was specified as {offenders[[1]]}, \\
-      but there is no column in `data` called {offenders[[1]]}."
+      "x" = "The {offenders_names[1L]} argument of \\
+      {name_current_fn} was specified as {offenders[[1L]]}, \\
+      but there is no column in `data` called {offenders[[1L]]}."
     )
 
     # ... to point out that more than one supplied value is flawed:
@@ -59,8 +59,8 @@ check_factory_key_args_values <- function(data, key_cols_call) {
       }
       msg_error <- append(
         msg_error, c(
-          "x" = "Same with the {offenders_names[-1]} {msg_arg_s}: \\
-          `data` doesn't contain {msg_a}{offenders[-1]} {msg_col}."
+          "x" = "Same with the {offenders_names[-1L]} {msg_arg_s}: \\
+          `data` doesn't contain {msg_a}{offenders[-1L]} {msg_col}."
         )
       )
     }
@@ -299,12 +299,12 @@ absorb_key_args <- function(data, reported, key_cols_call) {
 #' any other arguments, and it must be reassigned to `fun`, not to `data`.
 #'
 #' The function is not currently used because I'm now very skeptical of its
-#' utility and even its reliability. It uses on a style of function manipulation
-#' that might just be too intricate to be feasible in practice.
+#' utility and even its reliability. It relies on a style of function
+#' manipulation that might just be too intricate to use in practice.
 #'
-#' I originally attempted for `absorb_other_args()` to replace the dots on one
-#' level, thereby enabling their use on another level, but this solution was
-#' somewhat overengineered.
+#' I originally aimed for `absorb_other_args()` to replace the dots on one level
+#' of function calls, thereby enabling their use on another level, but this
+#' solution turned out to have been somewhat overengineered.
 #'
 #' @param fun Function to be applied.
 #' @param reported String. Names of the key arguments.
@@ -359,48 +359,45 @@ absorb_other_args <- function(fun, reported) {
 #'
 #' @noRd
 check_args_disabled <- function(args_disabled) {
-
-  # Enforce argument disabling via `args_disabled`:
-  if (!is.null(args_disabled)) {
-    arg_names_caller_call <- rlang::frame_call(frame = parent.frame())
-    arg_names_caller_call <- names(arg_names_caller_call)
-    offenders <- args_disabled[args_disabled %in% arg_names_caller_call]
-    if (length(offenders) > 0L) {
-      fun_name <- name_caller_call(n = 2L)
-      fun_name_bare <- name_caller_call(wrap = FALSE)
-      fun_name_bare <- as.character(fun_name_bare)
-      package_name <- utils::getAnywhere(fun_name_bare)$where
-      package_name <- as.character(package_name[1])
-      package_name <- sub("package:", "", package_name)
-      if (length(offenders) > 3L) {
-        offenders <- offenders[1:3]
-        msg_among_others <- ", among others"
-      } else {
-        msg_among_others <- ""
-      }
-      if (length(offenders) > 1L) {
-        msg_arg_s <- "Arguments"
-        msg_is_are <- "are"
-      } else {
-        msg_arg_s <- "Argument"
-        msg_is_are <- "is"
-      }
-      offenders <- wrap_in_backticks(offenders)
-      cli::cli_abort(c(
-        "{msg_arg_s} {offenders} {msg_is_are} \\
+  if (is.null(args_disabled)) {
+    return(NULL)
+  }
+  arg_names_caller_call <- rlang::frame_call(frame = parent.frame())
+  arg_names_caller_call <- names(arg_names_caller_call)
+  offenders <- args_disabled[args_disabled %in% arg_names_caller_call]
+  if (length(offenders) > 0L) {
+    fun_name <- name_caller_call(n = 2L)
+    fun_name_bare <- name_caller_call(wrap = FALSE)
+    fun_name_bare <- as.character(fun_name_bare)
+    package_name <- utils::getAnywhere(fun_name_bare)$where
+    package_name <- as.character(package_name[1L])
+    package_name <- sub("package:", "", package_name)
+    if (length(offenders) > 3L) {
+      offenders <- offenders[1:3]
+      msg_among_others <- ", among others"
+    } else {
+      msg_among_others <- ""
+    }
+    if (length(offenders) > 1L) {
+      msg_arg_s <- "Arguments"
+      msg_is_are <- "are"
+    } else {
+      msg_arg_s <- "Argument"
+      msg_is_are <- "is"
+    }
+    offenders <- wrap_in_backticks(offenders)
+    cli::cli_abort(c(
+      "{msg_arg_s} {offenders} {msg_is_are} \\
           disabled in {fun_name}{msg_among_others}.",
-        "i" = "This is by design. When {fun_name} was created \\
+      "i" = "This is by design. When {fun_name} was created \\
           within {package_name} using `scrutiny::function_map()`, \\
           this function factory's `.args_disabled` argument was \\
           specified so as to include {offenders}.",
-        "i" = "The purpose is to prevent hidden errors that \\
+      "i" = "The purpose is to prevent hidden errors that \\
           might otherwise arise due to certain arguments not \\
           working properly within `scrutiny::function_map()`."
-      ))
-    }
-    rm(arg_names_caller_call, offenders)
+    ))
   }
-
 }
 
 
@@ -468,15 +465,15 @@ check_args_disabled_unnamed <- function(args_disabled) {
 #' @param contains String. The presence of `contains` values in the classes of
 #'   `data` is tested via `stringr::str_detect()`. Note that the order among
 #'   `contains` values matters.
-#' @param all_classes Boolean. If set to `TRUE`, returns all classes with a
+#' @param all_classes Logical. If set to `TRUE`, returns all classes with a
 #'   length-1 `contains` value. (Other lengths will then throw an error.)
 #'   Default is `FALSE`.
-#' @param order_decreasing Boolean. If `TRUE` (the default), longer classes are
+#' @param order_decreasing Logical. If `TRUE` (the default), longer classes are
 #'   tested before shorter ones.
 #'
 #' @return
 #' - For `class_with()`, a string vector.
-#' - For `inherits_class_with()`, a length-1 Boolean vector.
+#' - For `inherits_class_with()`, a length-1 logical vector.
 #'
 #' @noRd
 class_with <- function(data, contains, all_classes = FALSE,
@@ -496,7 +493,7 @@ class_with <- function(data, contains, all_classes = FALSE,
     return(cd[stringr::str_detect(cd, contains)])
   }
 
-  cd_lengths <- vapply(cd, stringr::str_length, integer(1L))
+  cd_lengths <- vapply(cd, stringr::str_length, integer(1L), USE.NAMES = FALSE)
   cd <- cd[order(cd_lengths, decreasing = order_decreasing)]
 
   # Outer loop:
@@ -527,4 +524,3 @@ inherits_class_with <- function(data, contains, all_classes = FALSE,
   )) > 0L
 }
 
-
