@@ -1,5 +1,4 @@
 
-
 manage_extra_cols <- function(data, extra, other_cols) {
 
   # Throw error if `extra` is a wrong string; i.e., if there is no extra column
@@ -18,9 +17,10 @@ manage_extra_cols <- function(data, extra, other_cols) {
 
   # Throw error if `extra` is a wrong number; i.e., if that given number is
   # larger than the actual number of extra columns:
-  if (!is.infinite(extra) && is.numeric(extra) &&
-      any(c(extra, length(extra)) > length(other_cols))) {
-
+  if (
+    !is.infinite(extra) && is.numeric(extra) &&
+    any(c(extra, length(extra)) > length(other_cols))
+  ) {
     # Prepare error message:
     if (length(other_cols) == 0L) {
       msg_n_cols <- "there aren't any extra columns"
@@ -31,20 +31,17 @@ manage_extra_cols <- function(data, extra, other_cols) {
         "there are only {length(other_cols)} extra columns"
       )
     }
-
     if (length(extra) == 1L) {
       cli::cli_abort(c(
       "`extra` was specified as `{extra}`, for extra column number {extra}.",
       "x" = "This number is too high -- {msg_n_cols} in `data`."
       ))
     } else {
-
-      if (length(other_cols) < extra[1]) {
+      if (length(other_cols) < extra[1L]) {
         msg_num_length <- "These numbers are"
       } else {
         msg_num_length <- "That last number is"
       }
-
       cli::cli_abort(c(
       "`extra` was specified as `{rlang::enexprs(extra)}`.",
       "x" = "{msg_num_length} too high -- {msg_n_cols} in `data`."
@@ -52,7 +49,6 @@ manage_extra_cols <- function(data, extra, other_cols) {
     }
   }
 
-
   # Finally, make `other_cols` capture any and all extra columns, and return it:
   if (!is.infinite(extra) && length(other_cols) > 0L) {
     return(dplyr::select(other_cols, dplyr::all_of(extra)))
@@ -62,4 +58,3 @@ manage_extra_cols <- function(data, extra, other_cols) {
 
 }
 
-
